OneBitBool

Struct OneBitBool 

pub struct OneBitBool { /* private fields */ }

Implementations

Source

impl OneBitBool

pub fn from(bool: bool) -> Self

Create a new OneBitBool from a bool

Examples
use bit_bool::OneBitBool;
 
let b = OneBitBool::from(true);
pub fn empty() -> Self

Empty constructor

Examples
use bit_bool::OneBitBool;
 
let b = OneBitBool::empty();
 
assert_eq!(b, OneBitBool::from(false));
pub fn get_index(&self, index: usize) -> bool

Gets the value of the bit at the given index

Examples
use bit_bool::OneBitBool;
 
let b = OneBitBool::from(true);
 
assert_eq!(b.get_index(0), true);
pub fn change_index(&mut self, index: usize, value: bool)

Changes the value of the bit at the given index

Examples
use bit_bool::OneBitBool;
 
let mut b = OneBitBool::from(true);
 
b.change_index(0, false);